@@ -30,9 +30,6 @@
 #include <float.h>
 #include <limits.h>
 #include <ctype.h>
-#ifdef HAVE_STDINT_H
-#include <stdint.h> 
-#endif
 #include <sys/types.h>
 #include "cjson.h"
 
@@ -58,10 +55,10 @@ static int cJSON_strcasecmp( const char *s1, const char *s2 )
 		return ( s1 == s2 ) ? 0 : 1;
 	if ( ! s2 )
 		return 1;
-	for ( ; tolower((u_char)*s1) == tolower((u_char)*s2); ++s1, ++s2)
+	for ( ; tolower(*s1) == tolower(*s2); ++s1, ++s2)
 		if( *s1 == 0 )
 			return 0;
-	return tolower((u_char)*s1) - tolower((u_char)*s2);
+	return tolower(*(const unsigned char *)s1) - tolower(*(const unsigned char *)s2);
 }
 
 
