@@ -1,29 +1,12 @@
 /*
- * iperf, Copyright (c) 2014, 2015, 2016, The Regents of the University of
- * California, through Lawrence Berkeley National Laboratory (subject
- * to receipt of any required approvals from the U.S. Dept. of
- * Energy).  All rights reserved.
+ * Copyright (c) 2009-2014, The Regents of the University of California,
+ * through Lawrence Berkeley National Laboratory (subject to receipt of any
+ * required approvals from the U.S. Dept. of Energy).  All rights reserved.
  *
- * If you have questions about your rights to use or distribute this
- * software, please contact Berkeley Lab's Technology Transfer
- * Department at TTD@lbl.gov.
- *
- * NOTICE.  This software is owned by the U.S. Department of Energy.
- * As such, the U.S. Government has been granted for itself and others
- * acting on its behalf a paid-up, nonexclusive, irrevocable,
- * worldwide license in the Software to reproduce, prepare derivative
- * works, and perform publicly and display publicly.  Beginning five
- * (5) years after the date permission to assert copyright is obtained
- * from the U.S. Department of Energy, and subject to any subsequent
- * five (5) year renewals, the U.S. Government is granted for itself
- * and others acting on its behalf a paid-up, nonexclusive,
- * irrevocable, worldwide license in the Software to reproduce,
- * prepare derivative works, distribute copies to the public, perform
- * publicly and display publicly, and to permit others to do so.
- *
- * This code is distributed under a BSD style license, see the LICENSE
- * file for complete information.
+ * This code is distributed under a BSD style license, see the LICENSE file
+ * for complete information.
  */
+
 #include <errno.h>
 #include <setjmp.h>
 #include <stdio.h>
@@ -32,7 +15,6 @@
 #include <unistd.h>
 #include <signal.h>
 #include <sys/types.h>
-#include <netinet/in.h>
 #include <sys/select.h>
 #include <sys/uio.h>
 #include <arpa/inet.h>
@@ -40,15 +22,10 @@
 #include "iperf.h"
 #include "iperf_api.h"
 #include "iperf_util.h"
-#include "iperf_locale.h"
+#include "locale.h"
 #include "net.h"
 #include "timer.h"
 
-#if defined(HAVE_TCP_CONGESTION)
-#if !defined(TCP_CA_NAME_MAX)
-#define TCP_CA_NAME_MAX 16
-#endif /* TCP_CA_NAME_MAX */
-#endif /* HAVE_TCP_CONGESTION */
 
 int
 iperf_create_streams(struct iperf_test *test)
@@ -56,40 +33,11 @@ iperf_create_streams(struct iperf_test *test)
     int i, s;
     struct iperf_stream *sp;
 
-    int orig_bind_port = test->bind_port;
     for (i = 0; i < test->num_streams; ++i) {
 
-        test->bind_port = orig_bind_port;
-	if (orig_bind_port)
-	    test->bind_port += i;
         if ((s = test->protocol->connect(test)) < 0)
             return -1;
 
-#if defined(HAVE_TCP_CONGESTION)
-	if (test->protocol->id == Ptcp) {
-	    if (test->congestion) {
-		if (setsockopt(s, IPPROTO_TCP, TCP_CONGESTION, test->congestion, strlen(test->congestion)) < 0) {
-		    close(s);
-		    i_errno = IESETCONGESTION;
-		    return -1;
-		} 
-	    }
-	    {
-		int len = TCP_CA_NAME_MAX;
-		char ca[TCP_CA_NAME_MAX + 1];
-		if (getsockopt(s, IPPROTO_TCP, TCP_CONGESTION, ca, &len) < 0) {
-		    close(s);
-		    i_errno = IESETCONGESTION;
-		    return -1;
-		}
-		test->congestion_used = strdup(ca);
-		if (test->debug) {
-		    printf("Congestion algorithm is %s\n", test->congestion_used);
-		}
-	    }
-	}
-#endif /* HAVE_TCP_CONGESTION */
-
 	if (test->sender)
 	    FD_SET(s, &test->write_set);
 	else
@@ -320,8 +268,7 @@ iperf_connect(struct iperf_test *test)
 
     /* Create and connect the control channel */
     if (test->ctrl_sck < 0)
-	// Create the control channel using an ephemeral port
-	test->ctrl_sck = netdial(test->settings->domain, Ptcp, test->bind_address, 0, test->server_hostname, test->server_port);
+	test->ctrl_sck = netdial(test->settings->domain, Ptcp, test->bind_address, test->server_hostname, test->server_port);
     if (test->ctrl_sck < 0) {
         i_errno = IECONNECT;
         return -1;
@@ -359,6 +306,15 @@ iperf_client_end(struct iperf_test *test)
 }
 
 
+static jmp_buf sigend_jmp_buf;
+
+static void
+sigend_handler(int sig)
+{
+    longjmp(sigend_jmp_buf, 1);
+}
+
+
 int
 iperf_run_client(struct iperf_test * test)
 {
@@ -369,8 +325,13 @@ iperf_run_client(struct iperf_test * test)
     struct timeval* timeout = NULL;
     struct iperf_stream *sp;
 
+    /* Termination signals. */
+    iperf_catch_sigend(sigend_handler);
+    if (setjmp(sigend_jmp_buf))
+	iperf_got_sigend(test);
+
     if (test->affinity != -1)
-	if (iperf_setaffinity(test, test->affinity) != 0)
+	if (iperf_setaffinity(test->affinity) != 0)
 	    return -1;
 
     if (test->json_output)
@@ -383,8 +344,8 @@ iperf_run_client(struct iperf_test * test)
     } else if (test->verbose) {
 	iprintf(test, "%s\n", version);
 	iprintf(test, "%s", "");
-	iprintf(test, "%s\n", get_system_info());
-	iflush(test);
+	fflush(stdout);
+	system("uname -a");
     }
 
     /* Start the client and connect to the server */
@@ -448,7 +409,7 @@ iperf_run_client(struct iperf_test * test)
 	         (test->settings->bytes != 0 && test->bytes_sent >= test->settings->bytes) ||
 	         (test->settings->blocks != 0 && test->blocks_sent >= test->settings->blocks))) {
 
-		// Unset non-blocking for non-UDP tests
+		// Set non-blocking for non-UDP tests
 		if (test->protocol->id != Pudp) {
 		    SLIST_FOREACH(sp, &test->streams, streams) {
 			setnonblocking(sp->socket, 0);
@@ -482,7 +443,5 @@ iperf_run_client(struct iperf_test * test)
 	iprintf(test, "%s", report_done);
     }
 
-    iflush(test);
-
     return 0;
 }
