@@ -1,29 +1,12 @@
 /*
- * iperf, Copyright (c) 2014, 2015, The Regents of the University of
- * California, through Lawrence Berkeley National Laboratory (subject
- * to receipt of any required approvals from the U.S. Dept. of
- * Energy).  All rights reserved.
+ * Copyright (c) 2009-2013, The Regents of the University of California,
+ * through Lawrence Berkeley National Laboratory (subject to receipt of any
+ * required approvals from the U.S. Dept. of Energy).  All rights reserved.
  *
- * If you have questions about your rights to use or distribute this
- * software, please contact Berkeley Lab's Technology Transfer
- * Department at TTD@lbl.gov.
- *
- * NOTICE.  This software is owned by the U.S. Department of Energy.
- * As such, the U.S. Government has been granted for itself and others
- * acting on its behalf a paid-up, nonexclusive, irrevocable,
- * worldwide license in the Software to reproduce, prepare derivative
- * works, and perform publicly and display publicly.  Beginning five
- * (5) years after the date permission to assert copyright is obtained
- * from the U.S. Department of Energy, and subject to any subsequent
- * five (5) year renewals, the U.S. Government is granted for itself
- * and others acting on its behalf a paid-up, nonexclusive,
- * irrevocable, worldwide license in the Software to reproduce,
- * prepare derivative works, distribute copies to the public, perform
- * publicly and display publicly, and to permit others to do so.
- *
- * This code is distributed under a BSD style license, see the LICENSE
- * file for complete information.
+ * This code is distributed under a BSD style license, see the LICENSE file
+ * for complete information.
  */
+
 #include <stdio.h>
 #include <errno.h>
 #include <netdb.h>
@@ -45,16 +28,11 @@ iperf_err(struct iperf_test *test, const char *format, ...)
     if (test != NULL && test->json_output && test->json_top != NULL)
 	cJSON_AddStringToObject(test->json_top, "error", str);
     else
-	if (test && test->outfile) {
-	    fprintf(test->outfile, "iperf3: %s\n", str);
-	}
-	else {
-	    fprintf(stderr, "iperf3: %s\n", str);
-	}
+	fprintf(stderr, "iperf3: %s\n", str);
     va_end(argp);
 }
 
-/* Do a printf to stderr or log file as appropriate, then exit. */
+/* Do a printf to stderr, then exit. */
 void
 iperf_errexit(struct iperf_test *test, const char *format, ...)
 {
@@ -67,14 +45,8 @@ iperf_errexit(struct iperf_test *test, const char *format, ...)
 	cJSON_AddStringToObject(test->json_top, "error", str);
 	iperf_json_finish(test);
     } else
-	if (test && test->outfile) {
-	    fprintf(test->outfile, "iperf3: %s\n", str);
-	}
-	else {
-	    fprintf(stderr, "iperf3: %s\n", str);
-	}
+	fprintf(stderr, "iperf3: %s\n", str);
     va_end(argp);
-    iperf_delete_pidfile(test);
     exit(1);
 }
 
@@ -121,15 +93,6 @@ iperf_strerror(int i_errno)
         case IEINTERVAL:
             snprintf(errstr, len, "invalid report interval (min = %g, max = %g seconds)", MIN_INTERVAL, MAX_INTERVAL);
             break;
-        case IEBIND:
-            snprintf(errstr, len, "--bind must be specified to use --cport");
-            break;
-        case IEUDPBLOCKSIZE:
-            snprintf(errstr, len, "block size too large (maximum = %d bytes)", MAX_UDP_BLOCKSIZE);
-            break;
-	case IEBADTOS:
-	    snprintf(errstr, len, "bad TOS value (must be between 0 and 255 inclusive)");
-	    break;
         case IEMSS:
             snprintf(errstr, len, "TCP MSS too large (maximum = %d bytes)", MAX_MSS);
             break;
@@ -152,13 +115,6 @@ iperf_strerror(int i_errno)
         case IEENDCONDITIONS:
             snprintf(errstr, len, "only one test end condition (-t, -n, -k) may be specified");
             break;
-	case IELOGFILE:
-	    snprintf(errstr, len, "unable to open log file");
-	    perr = 1;
-	    break;
-	case IENOSCTP:
-	    snprintf(errstr, len, "no SCTP support available");
-	    break;
         case IENEWTEST:
             snprintf(errstr, len, "unable to create a new test");
             perr = 1;
@@ -244,11 +200,11 @@ iperf_strerror(int i_errno)
             snprintf(errstr, len, "the server is busy running a test. try again later");
             break;
         case IESETNODELAY:
-            snprintf(errstr, len, "unable to set TCP/SCTP NODELAY");
+            snprintf(errstr, len, "unable to set TCP NODELAY");
             perr = 1;
             break;
         case IESETMSS:
-            snprintf(errstr, len, "unable to set TCP/SCTP MSS");
+            snprintf(errstr, len, "unable to set TCP MSS");
             perr = 1;
             break;
         case IESETBUF:
@@ -338,22 +294,10 @@ iperf_strerror(int i_errno)
             snprintf(errstr, len, "unable to set TCP_CONGESTION: " 
                                   "Supplied congestion control algorithm not supported on this host");
             break;
-	case IEPIDFILE:
-            snprintf(errstr, len, "unable to write PID file");
-            perr = 1;
-            break;
 	case IEV6ONLY:
 	    snprintf(errstr, len, "Unable to set/reset IPV6_V6ONLY");
 	    perr = 1;
 	    break;
-        case IESETSCTPDISABLEFRAG:
-            snprintf(errstr, len, "unable to set SCTP_DISABLE_FRAGMENTS");
-            perr = 1;
-            break;
-        case IESETSCTPNSTREAM:
-            snprintf(errstr, len, "unable to set SCTP_INIT num of SCTP streams\n");
-            perr = 1;
-            break;
     }
 
     if (herr || perr)
